@@ -1,3 +1,7 @@
+"""Low-level interface to Invenio-backed APIs
+
+"""
+
 from .login import Login
 from .deposit import Deposit
 from .records import Records
